@@ -13,30 +13,33 @@
 
 namespace Botan {
 
-/*
-* Lightweight OpenSSL BN Wrapper
+/**
+* Lightweight OpenSSL BN wrapper. For internal use only.
 */
-class BOTAN_DLL OSSL_BN
+class OSSL_BN
    {
    public:
       BIGNUM* value;
 
       BigInt to_bigint() const;
-      void encode(byte[], u32bit) const;
-      u32bit bytes() const;
+      void encode(byte[], size_t) const;
+      size_t bytes() const;
+
+      SecureVector<byte> to_bytes() const
+         { return BigInt::encode(to_bigint()); }
 
       OSSL_BN& operator=(const OSSL_BN&);
 
       OSSL_BN(const OSSL_BN&);
       OSSL_BN(const BigInt& = 0);
-      OSSL_BN(const byte[], u32bit);
+      OSSL_BN(const byte[], size_t);
       ~OSSL_BN();
    };
 
-/*
-* Lightweight OpenSSL BN_CTX Wrapper
+/**
+* Lightweight OpenSSL BN_CTX wrapper. For internal use only.
 */
-class BOTAN_DLL OSSL_BN_CTX
+class OSSL_BN_CTX
    {
    public:
       BN_CTX* value;
