@@ -19,13 +19,8 @@ namespace Botan {
 */
 void PBE_PKCS5v15::write(const byte input[], size_t length)
    {
-   while(length)
-      {
-      size_t put = std::min(DEFAULT_BUFFERSIZE, length);
-      pipe.write(input, length);
-      flush_pipe(true);
-      length -= put;
-      }
+   pipe.write(input, length);
+   flush_pipe(true);
    }
 
 /*
@@ -95,7 +90,7 @@ void PBE_PKCS5v15::set_key(const std::string& passphrase)
 */
 void PBE_PKCS5v15::new_params(RandomNumberGenerator& rng)
    {
-   iterations = 10000;
+   iterations = 50000;
    salt = rng.random_vec(8);
    }
 
@@ -166,7 +161,7 @@ std::string PBE_PKCS5v15::name() const
 PBE_PKCS5v15::PBE_PKCS5v15(BlockCipher* cipher,
                            HashFunction* hash,
                            Cipher_Dir dir) :
-   direction(dir), block_cipher(cipher), hash_function(hash)
+   direction(dir), block_cipher(cipher), hash_function(hash), iterations(0)
    {
    if(cipher->name() != "DES" && cipher->name() != "RC2")
       {
